.. math::
    \lim_{k \to \infty}
    \frac{\| \mathbf{x}_{k+1} - \mathbf{x}^\star \|}{\| \mathbf{x}_{k} - \mathbf{x}^\star\|^q} = \mu

where :math:`\mathbf{x}_k` is the agent's local x at iteration k,
:math:`\mathbf{x}^\star` is the optimal x defined in the *problem*,
:math:`q` is the asymptotic convergence order,
and :math:`\mu` is the asymptotic convergence rate.
